@@ -40,7 +40,14 @@ void Player::PutCard(const Card& card)
 
 }
 
-void Player::CardsPlayed(std::vector<Card>& cards, bool ownCards, size_t round)
+void Player::CardsPlayed(std::vector<Card>& cards,
+                         bool ownCards,
+                         size_t round)
+{
+  // no code
+}
+
+void Player::RoundFinished(size_t round, size_t pointsMe, size_t pointsOther)
 {
   // no code
 }
