@@ -40,7 +40,12 @@ public:
 
   virtual SolutionSet PlayCard(const Table& table, size_t round) = 0;
 
-  virtual void CardsPlayed(std::vector<Card>& cards, bool ownCards, size_t round);
+  virtual void CardsPlayed(std::vector<Card>& cards,
+                           bool ownCards,
+                           size_t round);
+
+  virtual void RoundFinished(size_t round,
+                             size_t pointsMe, size_t pointsOther);
 
   virtual void PrintStatistics();
 };
