@@ -40,7 +40,6 @@
 #include <Lum/Label.h>
 #include <Lum/Menu.h>
 #include <Lum/Panel.h>
-#include <Lum/Space.h>
 #include <Lum/Text.h>
 
 // Game logic
@@ -194,14 +193,12 @@ public:
 
   void PreInit()
   {
-    Lum::Button *button;
     Lum::Grid   *grid;
     Lum::Label  *label;
     Lum::Panel  *horiz,*vert;
     Lum::Text   *text;
 
-    horiz=new Lum::HPanel();
-    horiz->SetFlex(true,true);
+    horiz=Lum::HPanel::Create(true,true);
 
     grid=new Lum::Grid();
     grid->SetFlex(true,true);
@@ -240,13 +237,11 @@ public:
 
     horiz->Add(grid);
 
-    horiz->Add(new Lum::HSpace());
+    horiz->AddSpace();
 
-    vert=new Lum::VPanel();
-    vert->SetFlex(false,true);
+    vert=Lum::VPanel::Create(false,true);
 
-    label=new Lum::Label();
-    label->SetFlex(true,false);
+    label=Lum::Label::Create(true,false);
 
     game=new Lum::Text();
     game->SetFlex(true,false);
@@ -278,36 +273,21 @@ public:
 
     vert->Add(label);
 
-    vert->Add(new Lum::VSpace());
+    vert->AddSpace();
 
-    button=new Lum::Button;
-    button->SetFlex(true,false);
-    button->SetModel(newGameAction);
-    button->SetText(_(L"GAME_NEW",L"_New Game"));
-    vert->Add(button);
+    vert->Add(Lum::Button::Create(_(L"GAME_NEW",L"_New Game"),newGameAction,true,false));
 
-    vert->Add(new Lum::VSpace(true));
+    vert->AddSpace(true);
 
     fadeText=new FadeText();
     fadeText->SetFlex(true,false);
     fadeText->AddText(_(L"TEXT_SCOPA!",L"Scopa!"));
     vert->Add(fadeText);
 
-    vert->Add(new Lum::VSpace(true));
-
-    button=new Lum::Button;
-    button->SetFlex(true,false);
-    button->SetModel(lastComputerMoveAction);
-    button->SetText(_(L"GAME_LAST_COMPUTER",L"_Last computer move"));
-    vert->Add(button);
-
-    vert->Add(new Lum::VSpace());
-
-    button=new Lum::Button;
-    button->SetFlex(true,false);
-    button->SetModel(lastHumanMoveAction);
-    button->SetText(_(L"GAME_LAST_HUMAN",L"_Last human move"));
-    vert->Add(button);
+    vert->AddSpace(true);
+    vert->Add(Lum::Button::Create(_(L"GAME_LAST_COMPUTER",L"_Last computer move"),lastComputerMoveAction,true,false));
+    vert->AddSpace();
+    vert->Add(Lum::Button::Create(_(L"GAME_LAST_HUMAN",L"_Last human move"),lastHumanMoveAction,true,false));
 
     horiz->Add(vert);
 
@@ -632,7 +612,9 @@ public:
 #endif
 
       for (size_t i=0; i<players.size(); i++) {
-        players[i]->CardsPlayed(collected,(i)==(currentPlayer%2),currentRound);
+        players[i]->CardsPlayed(collected,
+                                (i)==(currentPlayer%2),
+                                currentRound);
       }
 
       if (table->IsEmpty()) {
@@ -703,7 +685,9 @@ public:
 #endif
 
       for (size_t i=0; i<players.size(); i++) {
-        players[i]->CardsPlayed(collected,(i)==(currentPlayer%2),currentRound);
+        players[i]->CardsPlayed(collected,
+                                (i)==(currentPlayer%2),
+                                currentRound);
       }
 
       if (table->IsEmpty()) {
